@@ -1,6 +1,6 @@
 from abc import ABCMeta,abstractmethod
 
-from Victor.BaseVictor import BaseVictor
+from ..Victor.BaseVictor import BaseVictor
 class BaseEdge(object,metaclass=ABCMeta):
     @abstractmethod
     def __init__(self,id,name,from_victor:BaseVictor,to_victor:BaseVictor,type_):
