@@ -1,5 +1,5 @@
-from Edge.BaseEdge import BaseEdge
-from Victor.BaseVictor import BaseVictor
+from ..Edge.BaseEdge import BaseEdge
+from ..Victor.BaseVictor import BaseVictor
 
 
 class NormalEdge(BaseEdge):
