@@ -1,7 +1,6 @@
 
-
-from Victor.BaseVictor import BaseVictor
-from Edge.NormalEdge import NormalEdge
+from ..Victor.BaseVictor import BaseVictor
+from ..Edge.NormalEdge import NormalEdge
 
 class GraphNode:
     def __init__(self,victor:BaseVictor):
